boston311 API documentation
Description: Access service request data from the Boston 311 API.

# Package `boston311`

Access service request data from the Boston 311 API.

Expand source code

    """Access service request data from the Boston 311 API."""

    from .api import get_service_request, get_service_requests, get_services  # noqa: F401

    __version__ = "0.1.0"

## Sub-modules

`boston311.api`

  Interacting with the Boston 311 API.

`boston311.constants`

  Constants used throughout the project.

`boston311.datamodels`

  Data models.

`boston311.exceptions`

  Custom error types.

`boston311.formatting`

  Formatters and formatting.

`boston311.service_requests_parameters`

  Data model for handling logic in parameters of a 'service requests' request.